API Documentation
#################

Statistics of list of (x, y) pairs from calculator-style summation registers.

source code
***********

.. automodule:: pysumreg.sum_registers
    :members: 
    :synopsis: Calculator-style summation registers.
